django_turnit package
=====================

.. automodule:: django_turnit
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    django_turnit.backends
    django_turnit.fabfile
    django_turnit.management
    django_turnit.migrations
    django_turnit.templatetags

Submodules
----------

django_turnit.conf module
-------------------------

.. automodule:: django_turnit.conf
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.models module
---------------------------

.. automodule:: django_turnit.models
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.tests module
--------------------------

.. automodule:: django_turnit.tests
    :members:
    :undoc-members:
    :show-inheritance:

django_turnit.utilities module
------------------------------

.. automodule:: django_turnit.utilities
    :members:
    :undoc-members:
    :show-inheritance:


